@@ -2,7 +2,7 @@ from dataclasses import dataclass
 
 
 class BrokenLink(Exception):
-    print('Broken Link')
+    #Ignore these
     pass
 
 
